import { csvParse, select } from 'd3';
import { scatterPlot } from './scatterPlot';

export const viz = (container, { state, setState }) => {
  const width = window.innerWidth;
  const height = window.innerHeight;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  const { data } = state;

  if (data && data !== 'LOADING') {
    svg.call(scatterPlot, {
      data,
      width,
      height,
      xValue: (d) => d.horsepower,
      yValue: (d) => d.highway_mpg,
      shapeValue: (d) => d.make,
      xAxisLabel: 'Horsepower',
      yAxisLabel: 'Highway MPG',
      shapeLegendLabel: 'Make',
      margin: {
        top: 10,
        right: 10,
        bottom: 50,
        left: 120,
      },
      colorLegendX: 850,
      colorLegendY: 420,
    });
  }

  if (data === undefined) {
    setState((state) => ({
      ...state,
      data: 'LOADING',
    }));
    fetch(
      'https://gist.githubusercontent.com/AsheshPinisetti/7fb5d931276225cbc78064bd197a5948/raw/81314dd7a8c09f1d8a3cb00952942c7ece18c918/bubble.csv',
    )
      .then((response) => response.text())
      .then((csvString) => {
        const data = csvParse(csvString);

        for (const d of data) {
          d.horsepower = +d.horsepower;
          d.torque = +d.torque;
          d.highway_mpg = +d.highway_mpg;
        }

        setState((state) => ({
          ...state,
          data,
        }));
      });
  }
};
